"""Analytics REST service."""

from ._service import AnalyticsService
from ._decorators import MultiFrameHandling
